Flask Request Validator
=======================

Simply request validator for Flask. See `readme`_

Installation
------------

    $ pip install flask_request_validator

.. _readme: https://github.com/d-ganchar/flask_request_validator
